Documentation
¶
Overview ¶
Package fsgofer implements p9.File giving access to local files using a simple mapping from a path prefix that is added to the path requested by the sandbox. Ex:
prefix: "/docker/imgs/alpine" app path: /bin/ls => /docker/imgs/alpine/bin/ls
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Config ¶
type Config struct {
// ROMount is set to true if this is a readonly mount.
ROMount bool
// LazyOpenForWrite makes the underlying file to be opened in RDONLY
// mode initially and be reopened in case write access is desired.
// This is done to workaround the behavior in 'overlay2' that
// copies the entire file up eagerly when it's opened in write mode
// even if the file is never actually written to.
LazyOpenForWrite bool
}
Config sets configuration options for each attach point.
Click to show internal directories.
Click to hide internal directories.